Thanks for contributing a pull request! Please ensure you have taken a look at
the contribution guidelines: https://github.com/LeemanGeophysicalLLC/pylook/blob/master/CONTRIBUTING.md

#### Description Of Changes

#### Checklist
Feel free to remove check-list items aren't relevant to your change

Please use keywords (e.g., Fixes, Closes) to create link to the issues or pull
requests you resolved, so that they will automatically be closed when your pull
request is merged. See https://github.com/blog/1506-closing-issues-via-pull-requests

- [ ] Closes #xxxx
- [ ] Tests added
- [ ] Fully documented
